@@ -6,7 +6,7 @@ import tempfile
 from subprocess import Popen, PIPE
 import os
 
-from libfuturize.fixer_util import is_shebang_comment
+from libfuturize.fixer_util import is_shebang_comment, is_encoding_comment
 from lib2to3.fixer_util import FromImport
 from lib2to3.pytree import Leaf, Node
 from lib2to3.pygram import token
@@ -17,13 +17,63 @@ from future.utils import PY2
 
 
 class TestLibFuturize(unittest.TestCase):
+    @skip26    # mysterious sporadic UnicodeDecodeError raised by lib2to3 ...
+    def test_correct_exit_status(self):
+        """
+        Issue #119: futurize and pasteurize were not exiting with the correct
+        status code. This is because the status code returned from
+        libfuturize.main.main() etc. was a ``newint``, which sys.exit() always
+        translates into 1!
+        """
+        from libfuturize.main import main
+        # Try futurizing this test script:
+        retcode = main([__file__])
+        self.assertTrue(isinstance(retcode, int))   # i.e. Py2 builtin int
+
     def test_is_shebang_comment(self):
         """
-        Tests whether the libfuturize.fixer_util.is_shebang_comment() function is working
+        Tests whether the fixer_util.is_encoding_comment() function is working.
         """
-        node = FromImport(u'math', [Leaf(token.NAME, u'cos', prefix=" ")])
-        node.prefix = u'#!/usr/bin/env python\n'
-        self.assertTrue(is_shebang_comment(node))
+        shebang_comments = [u'#!/usr/bin/env python\n'
+                             u"#!/usr/bin/python2\n",
+                             u"#! /usr/bin/python3\n",
+                            ]
+        not_shebang_comments = [u"# I saw a giant python\n",
+                                 u"# I have never seen a python2\n",
+                               ]
+        for comment in shebang_comments:
+            node = FromImport(u'math', [Leaf(token.NAME, u'cos', prefix=" ")])
+            node.prefix = comment
+            self.assertTrue(is_shebang_comment(node))
+
+        for comment in not_shebang_comments:
+            node = FromImport(u'math', [Leaf(token.NAME, u'cos', prefix=" ")])
+            node.prefix = comment
+            self.assertFalse(is_shebang_comment(node))
+
+
+    def test_is_encoding_comment(self):
+        """
+        Tests whether the fixer_util.is_encoding_comment() function is working.
+        """
+        encoding_comments = [u"# coding: utf-8",
+                             u"# encoding: utf-8",
+                             u"# -*- coding: latin-1 -*-",
+                             u"# vim: set fileencoding=iso-8859-15 :",
+                            ]
+        not_encoding_comments = [u"# We use the file encoding utf-8",
+                                 u"coding = 'utf-8'",
+                                 u"encoding = 'utf-8'",
+                                ]
+        for comment in encoding_comments:
+            node = FromImport(u'math', [Leaf(token.NAME, u'cos', prefix=" ")])
+            node.prefix = comment
+            self.assertTrue(is_encoding_comment(node))
+
+        for comment in not_encoding_comments:
+            node = FromImport(u'math', [Leaf(token.NAME, u'cos', prefix=" ")])
+            node.prefix = comment
+            self.assertFalse(is_encoding_comment(node))
 
 
 class TestFuturizeSimple(CodeHandler):
@@ -36,6 +86,39 @@ class TestFuturizeSimple(CodeHandler):
         self.tempdir = tempfile.mkdtemp() + os.path.sep
         super(TestFuturizeSimple, self).setUp()
 
+    def test_encoding_comments_kept_at_top(self):
+        """
+        Issues #10 and #97: If there is a source encoding comment line
+        (PEP 263), is it kept at the top of a module by ``futurize``?
+        """
+        before = """
+        # coding=utf-8
+
+        print 'Hello'
+        """
+        after = """
+        # coding=utf-8
+
+        from __future__ import print_function
+        print('Hello')
+        """
+        self.convert_check(before, after)
+
+        before = """
+        #!/usr/bin/env python
+        # -*- coding: latin-1 -*-"
+
+        print 'Hello'
+        """
+        after = """
+        #!/usr/bin/env python
+        # -*- coding: latin-1 -*-"
+
+        from __future__ import print_function
+        print('Hello')
+        """
+        self.convert_check(before, after)
+
     def test_shebang_blank_with_future_division_import(self):
         """
         Issue #43: Is shebang line preserved as the first
@@ -355,7 +438,6 @@ class TestFuturizeSimple(CodeHandler):
         """
         self.convert_check(before, after, ignore_imports=False)
     
-    @expectedFailurePY26
     def test_source_coding_utf8(self):
         """
         Tests to ensure that the source coding line is not corrupted or
@@ -562,7 +644,7 @@ class TestFuturizeRenamedStdlib(CodeHandler):
         """
         after = """
         from future import standard_library
-        standard_library.install_hooks()
+        standard_library.install_aliases()
         import urllib.request
         
         URL = 'http://pypi.python.org/pypi/future/json'
@@ -1193,7 +1275,7 @@ class TestFuturizeAllImports(CodeHandler):
         from __future__ import division
         from __future__ import absolute_import
         from future import standard_library
-        standard_library.install_hooks()
+        standard_library.install_aliases()
         from builtins import range
         from builtins import *
         import math
